package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Jan 16, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 20
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ApiPost struct {
Subject string `json:"subject"`
MdBody string `json:"md_body"`
Visibility string `json:"visibility"`
IsPublished bool `json:"is_published"`
}
type RemoteApiPost struct {
ApiPost
ID string `json:"id"`
PublishedAt int64 `json:"published_at,omitempty"`
UpdatedAt int64 `json:"updated_at,omitempty"`
PublicURL string `json:"public_url"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.